package org.xbib.interlibrary.action.sru;

import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.URIResolver;
import javax.xml.transform.stream.StreamSource;

public class ClasspathUriResolver implements URIResolver {

    private final ClassLoader classLoader;

    public ClasspathUriResolver(ClassLoader classLoader) {
        this.classLoader = classLoader;
    }

    @Override
    public StreamSource resolve(String href, String base) throws TransformerException {
        String s = href;
        try {
            URI uri = URI.create(href);
            if (!uri.isAbsolute() && base != null) {
                s = new URI(base).resolve(href).getRawSchemeSpecificPart();
            }
        } catch (URISyntaxException e) {
            throw new TransformerException(e);
        }
        InputStream inputStream = classLoader.getResourceAsStream(s);
        if (inputStream == null) {
            throw new TransformerException("resource not found on class path: " + s);
        } else {
            return new StreamSource(inputStream);
        }
    }
}
