package org.xbib.interlibrary.action.sru;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;

/**
 * Constants for SRU
 */
public interface Constants {
    
    String SRW_NS_URI = "http://www.loc.gov/zing/srw/";

    String SEARCH_RETRIEVE_NS_URI = "http://docs.oasis-open.org/ns/search-ws/sruResponse";

    String SEARCH_RETRIEVE_OPERATION = "searchRetrieve";
    
    String SCAN_OPERATION = "scan";

    /**
     * The table below lists schemas in which records may be transferred. 
     * The list is not exhaustive. None are required to be supported, 
     * and any other schema (whether on the list below or not) may be 
     * supported in addition.
     * The Explain document lists the XML schemas for a given database in 
     * which records may be transferred. Every schemas is unambiguously 
     * identified by a URI and a server may assign a short name, which 
     * may or may not be the same as the short name listed in the table 
     * below (and may differ from the short name that another server assigns).
     */
    @SuppressWarnings("serial")
    Map<String, URI> RECORD_SCHEMAS = new HashMap<>() {
        {
            put("dc", URI.create("info:srw/schema/1/dc-v1.1"));
            put("diag", URI.create("info:srw/schema/1/diagnostic-v1.1"));
            put("zeerex", URI.create("http://explain.z3950.org/dtd/2.0/"));
            put("mods", URI.create("info:srw/schema/1/mods-v3.4"));
            put("onix", URI.create("info:srw/schema/1/onix-v2.0"));
            put("marcxml", URI.create("info:srw/schema/1/marcxml-v1.1"));
            put("marcxchange", URI.create("info:/srw/schema/9/marcxchange"));
            put("mx", URI.create("info:/srw/schema/9/marcxchange"));
            put("ead", URI.create("info:srw/schema/1/ead-2002"));
            put("rec", URI.create("info:srw/schema/2/rec-1.0"));
            put("unimarcxml", URI.create("info:srw/schema/8/unimarcxml-v0.1"));
            put("dlxs-bib", URI.create("info:/srw/schema/10/dlxs-bib-v1.0"));
            put("dcx", URI.create("info:/srw/schema/1/dcx-v1.0"));
            put("pica-XML", URI.create("info:srw/schema/5/picaXML-v1.0"));
            put("mads", URI.create("info:srw/schema/1/mads-v1.0"));
            put("isohold", URI.create("info:srw/schema/5/iso20775-v1.0"));
            put("pam", URI.create("info:srw/schema/11/pam-v2.1"));
        }};

    @SuppressWarnings("serial")
    Map<String,URI> RECORD_SCHEMA_NAMESPACES = new HashMap<>() {
        {
            put("mods", URI.create("http://www.loc.gov/mods/v3"));
            put("mx", URI.create("info:lc/xmlns/marcxchange-v1"));
            put("marcxml", URI.create("http://www.loc.gov/MARC21/slim"));
        }};
}
