package org.xbib.interlibrary.action.sru;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.stream.Collectors;
import org.xbib.interlibrary.api.action.AbstractAction;
import org.xbib.interlibrary.api.action.Action;
import org.xbib.interlibrary.api.action.ActionArguments;
import org.xbib.interlibrary.api.action.Response;
import org.xbib.interlibrary.api.action.Service;

public class SearchRetrieveAction extends AbstractAction<SearchRetrieveRequest, SearchRetrieveResponse, SearchRetrieveResponseBuilder, SearchRetrieveService, SearchRetrieveServiceProvider> {

    public static final SearchRetrieveAction INSTANCE = new SearchRetrieveAction();

    private static final Logger logger = Logger.getLogger(SearchRetrieveAction.class.getName());

    private List<SearchRetrieveService> services = new ArrayList<>();

    public SearchRetrieveAction() {
    }

    @Override
    public Action<SearchRetrieveRequest, SearchRetrieveResponse, SearchRetrieveResponseBuilder, SearchRetrieveService> getInstance() {
        return INSTANCE;
    }

    @Override
    public void init(ActionArguments arguments) {
        this.services = createServices("action.sru.service", arguments);
        logger.log(Level.INFO, () -> "services: " + services.size() + " (" +
                services.stream().map(Service::getName).collect(Collectors.joining(",")) + ")");
    }

    @Override
    public List<SearchRetrieveService> getServices() {
        return services;
    }

    @Override
    public SearchRetrieveResponseBuilder newResponseBuilder(SearchRetrieveRequest request) {
        return SearchRetrieveResponse.builder().setRequest(request);
    }

    @Override
    public SearchRetrieveResponseBuilder newEmptyResponseBuilder(SearchRetrieveRequest request) {
        return SearchRetrieveResponse.builder().setRequest(request).setStatus("global", Response.Status.EMPTY_RESPONSE);
    }

    @Override
    public SearchRetrieveResponseBuilder newErrorResponse(SearchRetrieveRequest request, Throwable throwable) {
        logger.log(Level.SEVERE, throwable.getMessage(), throwable);
        return SearchRetrieveResponse.builder().setRequest(request).setThrowable(throwable);
    }

    @Override
    protected boolean isServiceQualified(SearchRetrieveRequest request, SearchRetrieveService service) {
        return true;
    }
}
